Kecleon
=======

.. image:: https://travis-ci.com/Peilonrayz/kecleon.svg?branch=master
   :target: https://travis-ci.com/Peilonrayz/kecleon
   :alt: Build Status

About
-----

This is a skeleton project to have a standardized and concrete base for all projects.

Installation
------------

.. code:: shell

   $ python -m pip install kecleon

Documentation
-------------

Documentation is available `via GitHub <https://peilonrayz.github.io/kecleon/>`_.

Testing
-------

To run all tests run ``nox``. No venv is needed; nox makes all of them for us.

.. code:: shell

   $ python -m pip install --user nox
   $ git clone https://github.com/Peilonrayz/kecleon
   $ cd kecleon
   kecleon $ nox

License
-------

Kecleon is available under the MIT license.